@@ -76,13 +76,7 @@ sub process_file
     # Make sure the config file exists and is readable
     my $filename = $self->{LOADED_FILENAME};
     unless (-e $filename) {
-        if ($create and open my $config_fh, '>:utf8', "$filename") {
-            print $config_fh '<?xml version="1.0"?><email-reminder_user/>';
-            close $config_fh;
-        }
-        else {
-            die "File '$filename' does not exist and it is impossible to create it.\n";
-        }
+        die "File '$filename' does not exist.\n";
     }
     unless (-r $filename) {
         die "File '$filename' exists but is not readable.\n";
@@ -167,28 +161,6 @@ sub create_event
     return $event;
 }
 
-sub save
-{
-    my $self = shift;
-    my $verbose = shift;
-    my $filename = shift || $self->{LOADED_FILENAME};
-
-    my $xml_document = $self->{XML_DOC}->toString();
-    print $xml_document if $verbose;
-
-    # Overwrite the file
-    if (open my $out_fh, '>:utf8', "$filename") {
-        print $out_fh $xml_document;
-        print "Sucessfully wrote reminders to '$filename'\n" if $verbose;
-        close $out_fh;
-    }
-    else {
-        print STDERR "Cannot write to file '$filename', your changes have been lost.\n";
-    }
-
-    return 1;
-}
-
 sub get_model
 {
     my ($self, $type) = @_;
@@ -230,18 +202,6 @@ sub get_events
     return @events;
 }
 
-sub add_event
-{
-    my ($self, $event_type) = @_;
-    my $event = $self->create_event($event_type);
-    return 0 unless defined($event);
-
-    $event->set_name("<New Event>");
-    $event->set_reminders([0]); # default reminder: same day
-
-    return $self->{STORES}->{$event_type}->add_event($event);
-}
-
 # View/edit user properties
 
 sub _get_user_fname {
@@ -284,27 +244,4 @@ sub get_user_email
     return EmailReminder::Utils::get_node_value($self->{USER_NODE}, $EMAIL_TAG) || "";
 }
 
-sub set_user_fname
-{
-    my ($self, $new_fname) = @_;
-    return EmailReminder::Utils::set_node_value($self->{USER_NODE}, $FIRST_NAME_TAG, $new_fname);
-}
-
-sub set_user_lname
-{
-    my ($self, $new_lname) = @_;
-    return EmailReminder::Utils::set_node_value($self->{USER_NODE}, $LAST_NAME_TAG, $new_lname);
-}
-
-# Return 0 if the email was ignored (invalid)
-sub set_user_email
-{
-    my ($self, $new_email) = @_;
-    if (!$new_email || Email::Valid->address($new_email)) {
-        return EmailReminder::Utils::set_node_value($self->{USER_NODE}, $EMAIL_TAG, $new_email);        
-    } else {
-        return 0;
-    }
-}
-
 1;
