@@ -84,7 +84,7 @@ sub get_current_occurence_date
     # Set the day of the month where the event occurs, make sure the date is valid
     # (e.g. fix-up for event on the 31st when the month has only 30 days)
     my $current_occurence_date = ParseDate("$current_year-$current_month-$day");
-    while (UnixDate($current_occurence_date, "\%d") != $day) {
+    while ($current_occurence_date eq "" or UnixDate($current_occurence_date, "\%d") != $day) {
         $day -= 1;
         $current_occurence_date = ParseDate("$current_year-$current_month-$day");
     }
