@@ -20,12 +20,6 @@ package EmailReminder::MonthlyStore;
 use strict;
 use warnings;
 
-use Gtk2;
-use Glib::Object::Subclass
-    Glib::Object::,
-    interfaces => [ Gtk2::TreeModel:: ],
-    ;
-
 use EmailReminder::EventStore;
 use EmailReminder::MonthlyEvent;
 
@@ -61,20 +55,4 @@ sub get_event_column
     }
 }
 
-sub set_event_column
-{
-    my ($self, $event, $col, $new_value) = @_;
-    
-    if ($col == $NAME_INDEX) {
-        $event->set_name($new_value);
-    }
-    elsif ($col == $DAY_INDEX) {
-        $event->set_day($new_value);
-    }
-    else {
-        $self->EmailReminder::EventStore::set_event_column($event, $col, $new_value);
-    }
-    return 1;
-}
-
 1;
